==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-customcommand/translations/customcommand_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="188"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Configuração de comando personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="191"/>
        <source>Use icon from theme or browse file</source>
        <translation>Utilizar ícone do tema ou escolher um ficheiro</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="84"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Executar com &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Selecione o tipo de letra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="208"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="221"/>
        <source>Use %1 to display command output</source>
        <translation>Utilize %1 para mostrar o resultado do comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="181"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="198"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Rotação automática se o painel for vertical</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="74"/>
        <source>echo Configure...</source>
        <translation>Configuração de echo...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="77"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="288"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="305"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="322"/>
        <source>Command to run</source>
        <translation>Comando a executar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>Max Width</source>
        <translation>Largura máxima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>Repeat command after:</source>
        <translation>Repetir comando após:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="152"/>
        <source> second(s)</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="174"/>
        <source>Command outputs an image</source>
        <translation>O comando produz uma imagem</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="272"/>
        <source>Mouse Commands</source>
        <translation>Comandos com o rato</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <source>Click</source>
        <translation>Clique</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="295"/>
        <source>Wheel Up</source>
        <translation>Roda para cima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="312"/>
        <source>Wheel Down</source>
        <translation>Roda para baixo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Select Icon File</source>
        <translation>Selecionar ficheiro de ícones</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="149"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Imagens (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1.tar.xz: lxqt-panel-2.2.1/plugin-customcommand/translations/customcommand_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Clicar para mudar de cor</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Selecionar cor</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="197"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Configuração de comando personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use icon from theme or browse file</source>
        <translation>Utilizar ícone do tema ou escolher um ficheiro</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Executar com &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Selecione o tipo de letra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source>Use %1 to display command output</source>
        <translation>Utilize %1 para mostrar o resultado do comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Rotação automática se o painel for vertical</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
        <source>echo Configure...</source>
        <translation>Configuração de echo...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
        <source>Command to run</source>
        <translation>Comando a executar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
        <source>Max Width</source>
        <translation>Largura máxima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
        <source>Repeat command after:</source>
        <translation>Repetir comando após:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Text Color</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
        <source>Reset</source>
        <translation>Repor</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
        <source> second(s)</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
        <source>Command outputs an image</source>
        <translation>O comando produz uma imagem</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source>Tooltip</source>
        <translation>Dica</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Mouse Commands</source>
        <translation>Comandos com o rato</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
        <source>Click</source>
        <translation>Clique</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
        <source>Wheel Up</source>
        <translation>Roda para cima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
        <source>Wheel Down</source>
        <translation>Roda para baixo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Select Icon File</source>
        <translation>Selecionar ficheiro de ícones</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Imagens (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
